@@ -1,9 +1,12 @@
 // -*-Mode: C++;-*-
+/*
+ * $Id: Login.h,v 2.1 1999/03/09 01:03:55 ral Exp $;
+ * Include file for login-window
+ */
 #ifndef CLogin_included
 #define CLogin_included
 
 #include "LoginData.h"
-#include <klineedit.h>
 
 class CLogin : public LoginData
 {
@@ -12,10 +15,10 @@ class CLogin : public LoginData
 public:
     CLogin(QWidget* parent = NULL,const char* name = NULL);
     virtual ~CLogin();
-    const char*get_host()const{return HostEdit->text();}
-    const char*get_pass()const{return PassEdit->text();}
-    const char*get_user()const{return UserEdit->text();}
-    const char*get_port()const{return PortEdit->text();}
+    const char*get_host(){return HostEdit->text();}
+    const char*get_pass(){return PassEdit->text();}
+    const char*get_user(){return UserEdit->text();}
+    const char*get_port(){return PortEdit->text();}
 
 protected slots:
     void focus_user();
@@ -23,7 +26,5 @@ protected slots:
     void focus_password();
     void focus_ok();
     void keyPressEvent(QKeyEvent*e);
-protected:
-
 };
 #endif // CLogin_included
