@@ -13,37 +13,25 @@
 #include <qstrlist.h>
 #include <qlined.h>
 #include <qpushbt.h>
-#include <qlayout.h>
-#include <qmultilineedit.h>
 
 #include "PatternPair.h"
-#include "e_patternpair.h"
 #include "MultiTextInputData.h"
 
-class QFrame;
-
 class CMultiTextInput : public CMultiTextInputData
 {
     Q_OBJECT
 public:
     CMultiTextInput(QWidget* parent = NULL,const char* name = NULL);
     virtual ~CMultiTextInput();
-    void build_widgets(e_PatternList*which);
+    void build_widgets(PatternList*which);
     PatternList*get_entries(bool emptys_too=FALSE);
-
-protected:
+private:
     QList<QWidget>*EditList;
-    QVBoxLayout * EditLayout;
-    QVBoxLayout * ScrollLayout;
-    QFrame*FrameWidget;
-    void ResizeFrame();
-
-    int min_x;
-    int min_y;
+private slots:
+    void change_focus();
 
 protected slots:
-    virtual void keyPressEvent(QKeyEvent*e);
-    virtual void resizeEvent ( QResizeEvent * );
-    virtual void change_focus();
+    void keyPressEvent(QKeyEvent*e);
+
 };
 #endif // CMultiTextInput_included
