@@ -12,43 +12,40 @@
 
 #include "TableView.h"
 #include "globals.h"
-#include "my_sql.h"
+#include "mysqlw.h"
 #include "PatternPair.h"
-#include "e_patternpair.h"
 #include "MultiTextInput.h"
 #include "tabledescr.h"
 #include "selectoutfile.h"
 #include "converter.h"
 #include "stringlist.h"
-#include "stringres.h"
 
 #ifndef rcsid
-static const char rcsid[]="$Id: TableView.cpp,v 2.23 1999/11/13 07:16:14 ral Exp $";
+static const char rcsid[]="$Id: TableView.cpp,v 2.7 1999/07/31 19:52:37 ral Exp $";
+const char*tableview_rcs(){return rcsid;}
 #endif
 
 #define Inherited CTableViewData
 
-CTableView::CTableView (CMySql*_sql_server,QWidget* parent,const char* name)
+CTableView::CTableView (QWidget* parent,const char* name)
     :Inherited( parent, name )
 {
-    sql_server = _sql_server;
-    QString caption;
-    caption = CStringRes::get_string(125);caption+=" - ";caption+=CStringRes::get_string(106);
-    setCaption(caption);
-
+    setCaption( i18n("KMySQL - TableView") );
     KWM::setIcon(winId(),kapp->getIcon());
     KWM::setMiniIcon(winId(),kapp->getMiniIcon());
 
-    Current_Table_Fields.resize(0);
-    Current_Displayed_Fields.resize(0);
-    CurrentKeys.resize(0);
-
+    Current_Table_Fields=0;
+    Current_Displayed_Fields = 0;
     RefreshLists();    
     connect(OutputList,SIGNAL(selected(int,int)),this,SLOT(entrySelected(int)));
 }
 
 CTableView::~CTableView()
 {
+    if (Current_Displayed_Fields)
+	delete Current_Displayed_Fields;
+    if (Current_Table_Fields)
+	delete Current_Table_Fields;
 }
 
 void CTableView::RefreshLists()
@@ -58,19 +55,102 @@ void CTableView::RefreshLists()
 	OutputList->removeItem(0);
     }
     SelectDB->clear();
-    stringlist list;
-    sql_server->get_db_list("%",list);
-    if (!list.size())
+    stringlist*list = sql_server->get_db_list("%");
+    if (!list)
 	return;
-    for (stringlist::iterator iter = list.begin();iter != list.end();++iter) {
+    for (stringlist::iterator iter = list->begin();iter != list->end();++iter) {
 	SelectDB->insertItem(iter->c_str());
     }
+    delete list;
     db_select(0);
 }
 
 void CTableView::MakeRequest()
 {
-    _make_fetch_request();
+    stringlist erg;
+    ColumnList_iterator Field;
+    QString sort;
+    QString db;
+    QString table;
+    QString format;
+    unsigned int id;
+    int i;
+
+    table = TableSelect->currentText();
+    db = SelectDB->currentText();
+    sort = SortListBox->currentText();
+    if (Current_Displayed_Fields) {
+	delete Current_Displayed_Fields;Current_Displayed_Fields = 0;
+    }
+    OutputList->clear();    
+    if (sort.find("No Columns") != -1)
+	return;
+    Current_Displayed_Fields = new ColumnList;
+    Current_Displayed_Fields->resize(0);
+    for (id = 0; id < ColumnDisplay->count();id++) {
+	if (ColumnDisplay->isSelected(id)) {
+	    erg.push_back(ColumnDisplay->text(id));
+	    Field = FindTableItem(ColumnDisplay->text(id));
+	    if (Field) {
+		Current_Displayed_Fields->push_back(CColumnDescriptor(*Field));
+	    }
+	}
+    }
+    OutputList->clear();
+    while (OutputList->count()) {
+	OutputList->removeItem(0);
+    }
+    OutputList->repaint();
+    if (Current_Displayed_Fields->size() == 0) {
+	for (Field = Current_Table_Fields->begin();Field!=Current_Table_Fields->end();++Field) {
+	  Current_Displayed_Fields->push_back(CColumnDescriptor(*Field));
+	}  
+    }
+    i = 0;
+    OutputList->setNumCols(Current_Displayed_Fields->size());
+    for (Field = Current_Displayed_Fields->begin();Field!=Current_Displayed_Fields->end();++Field) {
+	OutputList->setColumn(i,Field->get_name());
+	i++;
+    }
+    stringlist SizePattern;
+    i = sql_server->fetch_rows(db,table,sort,&erg,
+			       (unsigned)OffsetSlider->value(),
+			       (unsigned)CountSlider->value(),0,&SizePattern);
+
+    stringlist::iterator erg_iter = erg.begin();
+    for (;erg_iter != erg.end();++erg_iter) {
+	if (erg.size() > 9) {
+	    OutputList->setAutoUpdate(false);
+	}
+	OutputList->appendItem(erg_iter->c_str());
+	if (erg.size() > 9) {
+	    OutputList->setAutoUpdate(true);
+	}
+    }
+
+    unsigned int counter=0;
+    unsigned int col_counter = OutputList->numCols();
+    const char*__pat = 0;
+    for (counter = 0; counter < col_counter; counter++){
+	if (SizePattern.size() > counter && (__pat = SizePattern[counter].c_str()) ) {
+	    int res = atoi(__pat);
+	    res = res < 1?10:res;
+	    res *= 8;
+	    res = res < 50?50:res;
+	    OutputList->setColumnWidth(counter, res);
+	}
+    }
+    OutputList->repaint();
+    
+    //hope you'll never see it
+    if (i < 0) {
+	display_error_box();
+    }
+    if (OutputList->count() > 0)
+	OutputList->setCurrentItem(0);
+    else
+	OutputSelected(-1);
+    OutputList->setFocus();
 }
 
 void CTableView::OffsetSet(int i)
@@ -123,22 +203,23 @@ void CTableView::db_select(int i)
     s = SelectDB->text(i);
     if (s.isEmpty())
 	return;
-    stringlist Result;
-    sql_server->get_table_list("%",s,Result);
+    stringlist*Result = sql_server->get_table_list("%",s);
     TableSelect->clear();
-    if (Result.size() == 0) {
+    if (!Result || Result->size() == 0) {
 	TableSelect->insertItem("No Tables");
 	table_select(0);
+	if (Result)
+	    delete Result;
 	return;
     }
-    if (sql_server->is_system_db(s)) {
+    if (s == (const char*)"mysql")
 	EmptyTableButton->setEnabled(false);
-    } else {
+    else
 	EmptyTableButton->setEnabled(true);
-    }
-    for (stringlist::iterator iter=Result.begin();iter!=Result.end();++iter) {
+    for (stringlist::iterator iter=Result->begin();iter!=Result->end();++iter) {
 	TableSelect->insertItem(iter->c_str());
     }
+    delete Result;
     table_select(0);
 }
 
@@ -154,32 +235,34 @@ void CTableView::table_select(int i)
 	OutputList->removeItem(0);
     }
     OutputList->repaint();
-    Current_Table_Fields.resize(0);
-    Current_Displayed_Fields.resize(0);
-
+    if (Current_Table_Fields) {
+	delete Current_Table_Fields;Current_Table_Fields = 0;
+    }
+    if (Current_Displayed_Fields) {
+	delete Current_Displayed_Fields;Current_Displayed_Fields = 0;
+    }
     if (s.isEmpty() || t.isEmpty()) {
 	SortListBox->insertItem("No Columns found");
 	set_buttons(FALSE);
 	ColumnDisplay->update();
 	return;
     }
-
     if (s.find("No Tables") > -1) {
 	SortListBox->insertItem("No Columns found");
 	set_buttons(FALSE);
 	ColumnDisplay->update();
 	return;
     }
-    sql_server->get_table_keys(t,s,CurrentKeys);
-    if (!sql_server->get_table_fields(t,s,Current_Table_Fields) || Current_Table_Fields.size()==0) {
+    Current_Table_Fields = sql_server->get_table_fields(t,s);
+    if (!Current_Table_Fields || Current_Table_Fields->size() == 0) {
 	SortListBox->insertItem("No Columns found");
 	ColumnDisplay->insertItem("No Columns found");
 	set_buttons(FALSE);
 	return;
     }
-    int count = 0;
-    OutputList->setNumCols(Current_Table_Fields.size());
-    for (ergebnis = Current_Table_Fields.begin();ergebnis!=Current_Table_Fields.end(); ++ergebnis){
+    int count = 0; 
+    OutputList->setNumCols(Current_Table_Fields->size());
+    for (ergebnis = Current_Table_Fields->begin();ergebnis!=Current_Table_Fields->end(); ++ergebnis){
 	ColumnDisplay->insertItem(ergebnis->get_name());
 	SortListBox->insertItem(ergebnis->get_name());
 	OutputList->setColumn(count,ergebnis->get_name());
@@ -195,8 +278,7 @@ void CTableView::table_select(int i)
 
 void CTableView::addRow()
 {
-    e_PatternList which;// = new e_PatternList;
-    PatternList*result = 0;
+    PatternList*which = new PatternList;
     ColumnList_iterator Field;
     int i;
     QString db;
@@ -204,40 +286,131 @@ void CTableView::addRow()
     CMultiTextInput edit(this);
     table = TableSelect->currentText();
     db = SelectDB->currentText();
-    for (Field = Current_Table_Fields.begin();Field != Current_Table_Fields.end();++Field) {
+    for (Field = Current_Table_Fields->begin();Field != Current_Table_Fields->end();++Field) {
 	if (!Field->is_AutoIncrement() ) {
-	    e_PatternIterator iter;
-	    which.push_back(e_patternpair(Field->get_name(),Field->get_default()));
-	    iter = which.end();
+	    PatternIterator iter;
+	    which->push_back(CPatternPair(Field->get_name(),Field->get_default()));
+	    iter = which->end();
 	    iter--;
 	    iter->setIsNumeric(Field->is_Numeric());
 	    iter->setLargeText(Field->is_Blob());
-	    stringIlist _temp_list = Field->enum_list();
-	    if (_temp_list.size()>0) {
-		if (!Field->is_NotNull())
-		    _temp_list.insert(_temp_list.begin(),"");
-		iter->set_enumlist(_temp_list);
-	    }
 	}
     }
-    edit.setCaption(CStringRes::get_string(77));
-    edit.build_widgets(&which);
+    edit.setCaption(i18n("Insert data"));
+    edit.build_widgets(which);
     if (edit.exec())
-        result = edit.get_entries(FALSE);
+        which = edit.get_entries(FALSE);
     else
 	return;
-    if (!result)
+    if (!which)
 	return;
-    i = sql_server->insert_row(db,table,result);
+    i = sql_server->insert_row(db,table,which);
     if (i < 0) {
 	display_error_box();
     }
-    delete result;
 }
 
 void CTableView::search_rows()
 {
-    _make_fetch_request(true);
+    stringlist erg;
+    stringlist sizes;
+    PatternList*pattern_list = new PatternList;
+    ColumnList_iterator Field;
+    QString sort;
+    QString db;
+    QString table;
+    QString format;
+    unsigned int id;
+    int i;
+    CMultiTextInput edit(this);
+
+    table = TableSelect->currentText();
+    db = SelectDB->currentText();
+    sort = SortListBox->currentText();
+    if (Current_Displayed_Fields) {
+	delete Current_Displayed_Fields;Current_Displayed_Fields = 0;
+    }    
+    if (sort.find("No Columns") != -1)
+	return;
+
+    Current_Displayed_Fields = new ColumnList;
+    for (id = 0; id < ColumnDisplay->count();id++) {
+	if (ColumnDisplay->isSelected(id)) {
+	    erg.push_back(ColumnDisplay->text(id));
+	    Field = FindTableItem(ColumnDisplay->text(id));
+	    if (Field) {
+		Current_Displayed_Fields->push_back(CColumnDescriptor(*Field));
+	    }
+	}
+    }
+    if (Current_Displayed_Fields->size() == 0) {
+	for (Field = Current_Table_Fields->begin();Field != Current_Table_Fields->end();++Field) {
+	  Current_Displayed_Fields->push_back(CColumnDescriptor(*Field));
+	}
+    }
+    for (Field = Current_Table_Fields->begin();Field!=Current_Table_Fields->end();++Field) {
+	PatternIterator p_iter;
+	pattern_list->push_back(CPatternPair(Field->get_name(),""));
+	p_iter = pattern_list->end();
+	--p_iter;
+	p_iter->setIsNumeric(Field->is_Numeric());
+	p_iter->setLargeText(Field->is_Blob());
+    }
+    edit.setCaption(i18n("Search (use % as wildcard!)"));
+    edit.build_widgets(pattern_list);
+    delete pattern_list;
+    if (edit.exec())
+	pattern_list = edit.get_entries(FALSE);
+    else
+	return;
+    //   OutputList->clear();
+    i = 0;
+    OutputList->clear();
+    while (OutputList->count()) {
+	OutputList->removeItem(0);
+    }
+    OutputList->setNumCols(Current_Displayed_Fields->size());
+ 
+    for (Field = Current_Displayed_Fields->begin();Field!=Current_Displayed_Fields->end();++Field) {
+	OutputList->setColumn(i,Field->get_name());
+	i++;
+    }
+
+    i = sql_server->fetch_rows(db,table,sort,&erg,(unsigned)OffsetSlider->value(),
+			       (unsigned)CountSlider->value(),pattern_list,&sizes);
+    if (pattern_list)
+	delete pattern_list;
+
+    stringlist::iterator erg_iter = erg.begin();
+
+    for (;erg_iter != erg.end();++erg_iter) {
+	if (erg.size() > 9) {
+	    OutputList->setAutoUpdate(false);
+	}
+	OutputList->appendItem(erg_iter->c_str());
+	if (erg.size() > 9) {
+	    OutputList->setAutoUpdate(true);
+	}
+    }
+
+    unsigned int counter=0;
+    unsigned int col_counter = OutputList->numCols();
+    const char*__pat = 0;
+    for (counter = 0; counter < col_counter; counter++){
+	if (sizes.size() > counter && (__pat = sizes[counter].c_str()) ) {
+	    int res = atoi(__pat);
+	    res = res < 1?10:res;
+	    res *= 8;
+	    res = res < 50?50:res;
+	    OutputList->setColumnWidth(counter, res);
+	}
+    }
+    OutputList->repaint();
+    //hope you'll never see it
+    if (i < 0) {
+	display_error_box();
+    }
+    OutputList->setFocus();
 }
 
 void CTableView::set_buttons(bool how)
@@ -264,37 +437,32 @@ void CTableView::modifyRow()
 {
     QString Entry;
     QString Breaks;
-    e_PatternList BreakList;// =  0;
-    PatternList* ModList = 0;
-    PatternList KeyList;// = 0;
-    PatternList _BreakList;
-
+    PatternList*BreakList =  0;
+    PatternList*ModList = 0;
+    PatternList*KeyList = 0;
+    /*
+      CPatternPair*dummy;
+      CPatternPair*dummy2;
+    */
     CMultiTextInput edit(this);
     int i = 0;
 
-    i = BreakIntoParts(&_BreakList,&KeyList);
-
-    if (i < 0 || _BreakList.size() == 0 || KeyList.size() == 0) {
+    BreakList = new PatternList;
+    //    BreakList->setAutoDelete(TRUE);
+    KeyList = new PatternList;
+    //    KeyList->setAutoDelete(TRUE);
+    i = BreakIntoParts(BreakList,KeyList);
+    if (i < 0 || BreakList->size() == 0 || KeyList->size() == 0) {
+	delete KeyList;
+	delete BreakList;
 	return;
     }
-    for (unsigned j = 0;j < _BreakList.size();++j) {
-	BreakList.push_back(_BreakList[j]);
-	for (unsigned a=0;a<Current_Displayed_Fields.size();++a) {
-	    if ( strcasecmp(BreakList[j].get_entry(),Current_Displayed_Fields[a].get_name()) == 0) {
-		stringIlist _temp_list = Current_Displayed_Fields[a].enum_list();
-		if (_temp_list.size()>0) {
-		    if (!Current_Displayed_Fields[a].is_NotNull())
-			_temp_list.insert(_temp_list.begin(),"");
-		    BreakList[j].set_enumlist(_temp_list);
-		}
-		break;
-	    }
-	}
-    }
-    edit.build_widgets(&BreakList);
 
+    edit.build_widgets(BreakList);
     edit.setCaption("Modify");
     if (!edit.exec()) {
+	delete BreakList;
+	delete KeyList;
 	return;
     }
 
@@ -303,14 +471,16 @@ void CTableView::modifyRow()
     if (!ModList || ModList->size() == 0) {
 	if (ModList)
 	    delete ModList;
+	delete BreakList;
+	delete KeyList;
 	return;	
     }
-    e_PatternIterator break_iter;
+    PatternIterator break_iter;
     PatternIterator mod_iter;
     
-    break_iter = BreakList.begin();
+    break_iter = BreakList->begin();
     mod_iter = ModList->begin();
-    while (break_iter!=BreakList.end()) {
+    while (break_iter!=BreakList->end()) {
 	Entry = mod_iter->get_pattern();
 	Breaks = break_iter->get_pattern();
 	if (Breaks == Entry) {
@@ -322,15 +492,19 @@ void CTableView::modifyRow()
     }
     if (ModList->size() == 0) {
 	delete ModList;
+	delete BreakList;
+	delete KeyList;
 	return;	
     }
     i = sql_server->update_row(SelectDB->currentText(),TableSelect->currentText(),
-		       ModList,&KeyList);
+		       ModList,KeyList);
+    delete KeyList;
     delete ModList;
-
+    delete BreakList;
     if (i < 0) {
 	display_error_box();
-    } else
+    }
+    else
 	MakeRequest();
 }
 
@@ -342,9 +516,9 @@ void CTableView::delete_row()
 	delete KeyList;
 	return;
     }
-    i = QMessageBox::warning( this, CStringRes::get_string(79),
-			      CStringRes::get_string(80),
-			      CStringRes::get_string(16), CStringRes::get_string(17),
+    i = QMessageBox::warning( this, i18n("Deleting row"),
+			      i18n("Do you realy want to delete this row?\n"),
+			      i18n("Of course"), i18n("Never!"),
 			      0, 1 );
     if (i == 1) {
 	delete KeyList;
@@ -354,20 +528,18 @@ void CTableView::delete_row()
     delete KeyList;
     if (i < 0) {
 	display_error_box();
-    } else {
-	MakeRequest();
     }
+    else
+	MakeRequest();
 }
 
 void CTableView::emptyTable()
 {
     QString message;
-    message = CStringRes::get_string(81);
-    message+="\n";
-    message+= CStringRes::get_string(14);
-    message+="\n";
-    int i = QMessageBox::warning( this, CStringRes::get_string(82),message,
-				  CStringRes::get_string(16), CStringRes::get_string(17),0, 1 );
+    message = i18n("Do you realy want to empty the complete table?\n");
+    message+= i18n("Realy all data will be lost!\n");
+    int i = QMessageBox::warning( this, i18n("Empty table"),message,
+			    i18n("Of course"), i18n("Never!"),0, 1 );
     if (i == 1)
 	return;
     i = sql_server->delete_row(SelectDB->currentText(),TableSelect->currentText());
@@ -384,25 +556,22 @@ void CTableView::emptyTable()
 
 bool CTableView::KeyDisplayed()
 {
-    if (SelectFields.size()==0) {
+    ColumnList_iterator Entry;
+    if (!Current_Displayed_Fields || Current_Displayed_Fields->size() < 1)
 	return false;
+    for (Entry = Current_Displayed_Fields->begin();Entry!=Current_Displayed_Fields->end();++Entry) {
+	if (Entry->is_KeyField() || Entry->is_Unique())
+	    return true;
     }
-    return true;
+    return false;
 }
 
-CColumnDescriptor*CTableView::FindTableItem(const char*what,bool all_fields)
+CColumnDescriptor*CTableView::FindTableItem(const char*what)
 {
     ColumnList_iterator Entry;
-    if (all_fields) {
-	for (Entry = Current_Table_Fields.begin();Entry!=Current_Table_Fields.end();++Entry) {
-	    if (*Entry == what)
-		return Entry;
-	}
-    } else {
-	for (Entry = Current_Displayed_Fields.begin();Entry!=Current_Displayed_Fields.end();++Entry) {
-	    if (*Entry == what)
-		return Entry;
-	}
+    for (Entry = Current_Table_Fields->begin();Entry!=Current_Table_Fields->end();++Entry) {
+	if (*Entry == what)
+	    return Entry;
     }
     return NULL;
 }
@@ -415,7 +584,7 @@ int CTableView::BreakIntoParts(PatternList*BreakList,PatternList*KeyList,int cou
     ColumnList_iterator Field;
     int i = OutputList->currentItem();
 
-    if (i < 0 || Current_Displayed_Fields.size() == 0)
+    if (i < 0 || Current_Displayed_Fields == 0)
 	return -1;
     if (count > -1)
 	Entry = OutputList->text(count);
@@ -446,7 +615,7 @@ int CTableView::BreakIntoParts(PatternList*BreakList,PatternList*KeyList,int cou
 	break_iterator = BreakList->begin();
     if (KeyList)
 	key_iterator= KeyList->begin();
-    for (Field = Current_Displayed_Fields.begin();Field!=Current_Displayed_Fields.end();++Field) {
+    for (Field = Current_Displayed_Fields->begin();Field!=Current_Displayed_Fields->end();++Field) {
 	if (BreakList) {
 	    if (Field->is_AutoIncrement() && !no_auto_filter) {
 		break_iterator = BreakList->erase(break_iterator);
@@ -459,7 +628,7 @@ int CTableView::BreakIntoParts(PatternList*BreakList,PatternList*KeyList,int cou
 	    }
 	}
 	if (KeyList) {
-	    if (SelectFields.find(Field->get_name())) {
+	    if (Field->is_KeyField()) {
 		if (key_iterator) {
 		    key_iterator->set_entry(Field->get_name());
 		    ++key_iterator;
@@ -488,24 +657,23 @@ void CTableView::saveResult()
 	return;
     finfo.setFile(filename);
     if (finfo.isDir()) {
-	QMessageBox::warning(this,CStringRes::get_string(83),
-			     CStringRes::get_string(84));
+	QMessageBox::warning(this,i18n("Error open file"),
+			     i18n("This is a directory, not a file!!!"));
 	return;
     }
     if (QFile::exists(filename)) {
-	message = CStringRes::get_string(85);
+	message = i18n("The file");
 	message+="\n\n";
 	message+=filename;message+="\n\n";
-	message+=CStringRes::get_string(86);
-	message+="\n";
-	i = KMsgBox::yesNo( this, CStringRes::get_string(87),
+	message+=i18n("does exists. Overwrite?\n");
+	i = KMsgBox::yesNo( this, i18n("Overwriting file"),
 			    message,KMsgBox::QUESTION);
 	if (i != 1 )
 	    return;
 
 	if (!finfo.isWritable()) {
-	    QMessageBox::warning(this,CStringRes::get_string(83),
-				CStringRes::get_string(88));
+	    QMessageBox::warning(this,i18n("Error open file"),
+				 i18n("You have no write permission!"));
 	    return;
 	}
     }
@@ -577,7 +745,7 @@ void CTableView::saveHtml(const char*filename)
     st << "<HTML>\n<HEAD>\n<TITLE>TableOutput</TITLE>\n</HEAD>\n";
     st << "<BODY>\n<TABLE WIDTH=100% BORDER=1 CELLPADDING=3 CELLSPACING=1>\n";
     st << "  <TR VALIGN=TOP>\n";
-    for (desc = Current_Displayed_Fields.begin();desc!= Current_Displayed_Fields.end();++desc) {
+    for (desc = Current_Displayed_Fields->begin();desc!= Current_Displayed_Fields->end();++desc) {
 	st << "    <TH><P>" << desc->get_name() << "</TH>\n";
     }
     st << "  </TR>\n";
@@ -587,7 +755,7 @@ void CTableView::saveHtml(const char*filename)
 	KeyList->resize(0);
 	BreakIntoParts(KeyList,0,i,true);
 	st << "  <TR>\n";
-	desc = Current_Displayed_Fields.begin();
+	desc = Current_Displayed_Fields->begin();
 	key_iterator = KeyList->begin();
 	for (key_iterator = KeyList->begin();key_iterator != KeyList->end();++key_iterator) {
 	    if (desc && desc->is_Numeric())
@@ -615,7 +783,7 @@ void CTableView::saveHtml(const char*filename)
 
 void CTableView::saveLatex(const char*filename)
 {
-    PatternList BreakList;
+    PatternList*KeyList = 0;
     CConverter * converter = CConverter::get_converter(CConverter::LATEX);
     if (!converter)
 	return;
@@ -631,45 +799,44 @@ void CTableView::saveLatex(const char*filename)
 	return;
     if (OutputList->count() < 1)
 	return;
+    //    QFile outfile(filename);
+    //    outfile.open(IO_WriteOnly|IO_Truncate);
+    //    if (!outfile.isOpen()) 
+    //	return;
+    //  QTextStream st(&outfile);
     ofstream st(filename);
     if (!st) {
-	QMessageBox::critical(this,CStringRes::get_string(112),CStringRes::get_string(83));
+	QMessageBox::critical(this,i18n("Error"),i18n("Error open file"));
 	return;
     }
-    unsigned int with = Current_Displayed_Fields.size();
     st << "\\documentclass[10pt,a4paper]{article}\n";
-    with = 120/with;
     st << "\\usepackage[latin1]{inputenc}\n";
-    st << "\\newcommand{\\tabcenter}[1]{\\multicolumn{1}{|c|}{#1}}\n";
-    st << "\\newcommand{\\tabright}[1]{\\multicolumn{1}{|r|}{#1}}\n";
-    char Buffer[100];
-    sprintf(Buffer,"%u",with);
-
-    head = "\\begin{tabular}{|";
-    for (i  = 0;i < Current_Displayed_Fields.size();++i ) {
-	head+="p{";
-	head+=Buffer;
-	head+="mm}|";
-    }
-    st << "\n\\begin{document}\n";
+    st << "\\begin{document}\n";
     st << "{\\Large\n{\\bf Database:} ";
     st << converter->convert(SelectDB->currentText()) << "\n";
     st << "\n{\\bf Table:} ";
     st << converter->convert(TableSelect->currentText()) << "\n";
     st << "}\n\n\\bigskip\n";
-
+    head = "\\begin{tabular}{|";
+    for (desc = Current_Displayed_Fields->begin();desc!= Current_Displayed_Fields->end();++desc ) {
+	if (desc->is_Numeric()) {
+	    head += "r|";
+	}
+	else {
+	    head+="l|";
+	}
+    }
     head+="}\\hline\n";
     head2 = head;
     head3 = "";
-    for (desc = Current_Displayed_Fields.begin();desc!= Current_Displayed_Fields.end();++desc ) {
-        if (desc != Current_Displayed_Fields.begin()) {
+    for (desc = Current_Displayed_Fields->begin();desc!= Current_Displayed_Fields->end();++desc ) {
+        if (desc != Current_Displayed_Fields->begin()) {
 	    head3+=" & ";
 	}
 	string dummy = converter->convert(desc->get_name());
 	if (!dummy.empty()) {
-	    head3+="\\tabcenter{\\bf ";
+	    head3+="\\bf ";
 	    head3+=dummy;
-	    head3+="}";
 	}
 	else {
 	    head3+=" ";
@@ -677,15 +844,17 @@ void CTableView::saveLatex(const char*filename)
     }
     head3 += "\\\\ \\hline\n";
     st << head << head3;
-    PatternIterator break_iterator;
+    KeyList = new PatternList;
+    PatternIterator key_iterator;
+    //    KeyList->setAutoDelete(true);
     j = 0;
     for (i = 0; i < OutputList->count();i++) {
-	BreakList.resize(0);
-	BreakIntoParts(&BreakList,0,i,true);
-	for (break_iterator=BreakList.begin();break_iterator!=BreakList.end();++break_iterator) {
-	    if (break_iterator != BreakList.begin())
+	KeyList->resize(0);
+	BreakIntoParts(KeyList,0,i,true);
+	for (key_iterator=KeyList->begin();key_iterator!=KeyList->end();++key_iterator) {
+	    if (key_iterator != KeyList->begin())
 		st << " & ";
-	    QString dummy = converter->convert(break_iterator->get_pattern());
+	    QString dummy = converter->convert(key_iterator->get_pattern());
 	    if (!dummy.isEmpty()) {
 		st << dummy;
 	    }
@@ -694,11 +863,11 @@ void CTableView::saveLatex(const char*filename)
 	    }
 	}
 	st << "\\\\ \\hline\n";
-	if (j == (35+pageoffset*5)) {
-	    st << "\\multicolumn{" << BreakList.size() << "}{|"
+	if (j == (39+pageoffset*5)) {
+	    st << "\\multicolumn{" << KeyList->size() << "}{|"
 		"r|}{\\small\\sl continued on next page}\\\\ \\hline";
 	    st << "\\end{tabular}\n%table to long for one side%\n\n" << head2;
-	    st << "\\multicolumn{" << BreakList.size() << "}{|l|}"
+	    st << "\\multicolumn{" << KeyList->size() << "}{|l|}"
 		"{\\small\\sl continued from previous}\\\\ \\hline" << head3;
 	    j = 0;
 	    pageoffset = 1;
@@ -718,177 +887,3 @@ void CTableView::entrySelected(int)
     if (ModifyRow->isEnabled())
 	modifyRow();
 }
-
-void CTableView::build_relevant_keys()
-{
-    pairIlist e_list;
-    bool all_found;
-    SelectFields.resize(0);
-    unsigned int count;
-    if (!Current_Displayed_Fields.size() || !CurrentKeys.size()) {
-	return;
-    }
-    KeyList::iterator k_iterator = CurrentKeys.begin();
-    while(k_iterator != CurrentKeys.end()) {
-	if (!k_iterator->is_UniqueKey()) {
-	    CurrentKeys.erase(k_iterator);
-	} else {
-	    ++k_iterator;
-	}
-    }
-    if (!CurrentKeys.size()) {
-	return;
-    }
-    for(k_iterator=CurrentKeys.begin();k_iterator!=CurrentKeys.end();++k_iterator) {
-	all_found = true;
-	e_list = k_iterator->get_ColList();
-	for (count = 0;count < e_list.size();++count) {
-	    all_found = FindTableItem(e_list[count].first.c_str(),false) != 0;
-	    if (!all_found)
-		break;
-	}
-	if (all_found) {
-	    for (count = 0; count < e_list.size();++count) {
-		if (! SelectFields.find(e_list[count].first)) {
-		    SelectFields.push_back(e_list[count].first);
-		}
-	    }
-	}
-    }
-}
-
-void CTableView::_make_fetch_request(bool search_it) 
-{
-    stringlist erg;
-    ColumnList_iterator Field;
-    QString sort;
-    QString db;
-    QString table;
-    QString format;
-    unsigned int id;
-    int i;
-
-    e_PatternList pattern_list;
-    PatternList*result = 0;
-
-    CMultiTextInput edit(this);
-    
-    table = TableSelect->currentText();
-    db = SelectDB->currentText();
-    sort = SortListBox->currentText();
-    Current_Displayed_Fields.resize(0);
-    OutputList->clear();
-    //    OutputList->resizeList(0);
-    if (sort.find("No Columns") != -1)
-	return;
-    for (id = 0; id < ColumnDisplay->count();id++) {
-	if (ColumnDisplay->isSelected(id)) {
-	    erg.push_back(ColumnDisplay->text(id));
-	    Field = FindTableItem(ColumnDisplay->text(id));
-	    if (Field) {
-		//		Current_Displayed_Fields.push_back(CColumnDescriptor(*Field));
-		Current_Displayed_Fields.push_back(*Field);
-	    }
-	}
-    }
-    OutputList->clear();
-    while (OutputList->count()) {
-	OutputList->removeItem(0);
-    }
-    OutputList->repaint();
-    if (Current_Displayed_Fields.size() == 0) {
-	for (Field = Current_Table_Fields.begin();Field!=Current_Table_Fields.end();++Field) {
-	    Current_Displayed_Fields.push_back(CColumnDescriptor(*Field));
-	}  
-    }
-    build_relevant_keys();
-
-    if (search_it) {
-	//pattern_list = new PatternList;
-	for (Field = Current_Table_Fields.begin();Field != Current_Table_Fields.end();++Field) {
-	    e_PatternIterator p_iter;
-	    pattern_list.push_back(e_patternpair(Field->get_name(),""));
-	    p_iter = pattern_list.end();
-	    --p_iter;
-	    p_iter->setIsNumeric(Field->is_Numeric());
-	    p_iter->setLargeText(Field->is_Blob());
-	    stringIlist _temp_enums = Field->enum_list();
-	    if (_temp_enums.size() > 0) {
-		// we requires the empy one, too
-		_temp_enums.insert(_temp_enums.begin(),"");
-		p_iter->set_enumlist(_temp_enums);
-	    }
-	}
-	edit.setCaption(CStringRes::get_string(78));
-	edit.build_widgets(&pattern_list);
-	if (edit.exec()) {
-	    result = edit.get_entries(FALSE);
-	} else {
-	    return;
-	}
-    }
-
-    i = 0;
-
-    OutputList->setNumCols(Current_Displayed_Fields.size());
-
-    for (Field = Current_Displayed_Fields.begin();Field!=Current_Displayed_Fields.end();++Field) {
-	OutputList->setColumn(i,Field->get_name());
-	i++;
-    }
-    stringlist SizePattern;
-    KApplication::getKApplication()->processEvents(100);
-    i = sql_server->fetch_rows(db,table,sort,&erg,
-			       (unsigned)OffsetSlider->value(),
-			       (unsigned)CountSlider->value(),result,&SizePattern);
-
-    if (result) {
-	delete result;
-	result = 0;
-    }
-    KApplication::getKApplication()->processEvents(100);
-    stringlist::iterator erg_iter = erg.begin();
-    if (erg.size() > 9) {
-	OutputList->setAutoUpdate(false);
-    }
-    QFont font( "Courier", 12, 50, 0 );
-    font.setStyleHint( (QFont::StyleHint)0 );
-    font.setCharSet( (QFont::CharSet)0 );
-    OutputList->setTableFont( font );
-    int updatecounter = 0;
-    for (;erg_iter != erg.end();++erg_iter) {
-	OutputList->appendItem(erg_iter->c_str());
-	++updatecounter;
-	if (updatecounter == 500) {
-	    KApplication::getKApplication()->processEvents(10);
-	    updatecounter = 0;
-	}
-    }
-    if (erg.size() > 9) {
-	OutputList->setAutoUpdate(true);
-	OutputList->repaint();
-    }
-    unsigned int counter=0;
-    unsigned int col_counter = OutputList->numCols();
-    const char*__pat = 0;
-    for (counter = 0; counter < col_counter; counter++){
-	if (SizePattern.size() > counter && (__pat = SizePattern[counter].c_str()) ) {
-	    int res = atoi(__pat);
-	    res = res < 1?10:res;
-	    res *= 8;
-	    res = res < 50?50:res;
-	    OutputList->setColumnWidth(counter, res);
-	}
-    }
-    OutputList->repaint();
-
-    //hope you'll never see it
-    if (i < 0) {
-	display_error_box();
-    }
-    if (OutputList->count() > 0)
-	OutputList->setCurrentItem(0);
-    else
-	OutputSelected(-1);
-    OutputList->setFocus();
-}
