@@ -1,6 +1,6 @@
 // -*-Mode: C++;-*-  
 /*
- * $Id: TableView.h,v 2.6 1999/11/07 15:42:05 ral Exp $
+ * $Id: TableView.h,v 2.3 1999/07/31 00:51:56 ral Exp $
  */
 
 #ifndef CTableView_included
@@ -13,15 +13,13 @@
 #include "PatternPair.h"
 #include "stringlist.h"
 
-class CMySql;
-
 class CTableView : public CTableViewData
 {
     Q_OBJECT
 
 public:
 
-    CTableView (CMySql*_sql_server,QWidget* parent = NULL, const char* name = NULL);
+    CTableView (QWidget* parent = NULL, const char* name = NULL);
 
     virtual ~CTableView();
 protected slots:
@@ -44,24 +42,17 @@ public slots:
     void show();
     void RefreshLists();
 
-protected:
-    CMySql*sql_server;
-    ColumnList Current_Table_Fields;
-    ColumnList Current_Displayed_Fields;
-    KeyList CurrentKeys;
-    stringlist SelectFields;
- 
+private:
+    ColumnList *Current_Table_Fields;
+    ColumnList *Current_Displayed_Fields;
     void set_buttons(bool how);
     bool KeyDisplayed();
-    CColumnDescriptor*FindTableItem(const char*what,bool all_fields=true);
+    CColumnDescriptor*FindTableItem(const char*what);
     int BreakIntoParts(PatternList*BreakList,PatternList*KeyList=0,
 		       int count = -1,bool no_auto_filter = false);
     void saveAscii(const char*filename);
     void saveHtml(const char*filename);
     void saveLatex(const char*filename);
-    
-    void build_relevant_keys();
-    void _make_fetch_request(bool search_it=false);
 };
 
 #endif // CTableView_included
