@@ -1,4 +1,8 @@
 // -*-Mode: C++;-*-
+/*
+ * $Id: TextInput.h,v 2.1 1999/03/09 01:03:59 ral Exp $;
+ * Header file for CTextInput
+ */
 #ifndef CTextInput_included
 #define CTextInput_included
 
@@ -11,11 +15,10 @@ public:
     CTextInput (QWidget* parent = NULL,const char* name = NULL);
     virtual ~CTextInput();
     const char*get_text(){return InputField->text();}
-    void set_label_text(const char*text);
 
 protected slots:
     void accept_field();
-    void inputChanged(const QString&);
+    void inputChanged(const char*);
 
 };
 #endif // CTextInput_included
