@@ -1,12 +1,14 @@
 // -*-Mode: C++;-*- 
+/*
+ * $Id: ThreadView.h,v 2.1 1999/03/09 01:03:59 ral Exp $
+ * Include file for the thread-view-object
+ */
+
 #ifndef CThreadView_included
 #define CThreadView_included
 
 #include "ListViewData.h"
 #include "qtimer.h"
-#include "helpers/smart_pointer.h"
-
-class CMySql;
 
 class CThreadView : public CListViewData
 {
@@ -14,19 +16,17 @@ class CThreadView : public CListViewData
 
 public:
 
-    CThreadView(smart_pointer<CMySql>& _sql_server,QWidget* parent = NULL,const char* name = NULL);
+    CThreadView(QWidget* parent = NULL,const char* name = NULL);
+
     virtual ~CThreadView();
 
 protected slots:
     void RefreshList();
     void KillThread();
-    void newTimeout(int aValue);
-    void NewFixedFont();
 
-protected:
-    smart_pointer<CMySql> sql_server;
+private:
     QTimer*ResetTimer;
-    int m_Timeout;
+    QPushButton*KillButton;
 
 public slots:
     void hide();
