@@ -20,21 +20,21 @@
 #ifndef CONVERTER_H
 #define CONVERTER_H
 
-#include "kmysqladmin/helpers/stringlist.h"
+#include "stringlist.h"
 #include <string>
-#include "kmysqladmin/helpers/smart_pointer.h"
 
 /**
- *Base class for converting strings into other text for instance ASCII into HTML
- *
- *@author Rajko Albrecht
- */
+  *Base class for converting strings into other text for instance ASCII into HTML
+  *
+  *@author Rajko Albrecht
+  *@version $Id: converter.h,v 2.5 1999/07/31 19:52:38 ral Exp $
+  */
 
-class CConverter:virtual public ref_count {
+class CConverter {
 public:
-    /**
-     * Types of converter known
-     */
+	/**
+	 * Types of converter known
+	 */
     enum ConvertTypes {HTML,LATEX};
     /** Constructor */
     CConverter();
@@ -48,12 +48,12 @@ public:
      */
     static CConverter* get_converter(ConvertTypes type);
     virtual ~CConverter();
-    const std::string&convert(const std::string&what);
-    const std::string&get_original()const{return source;}
-    const std::string&get_result()const{return dest;}
+    const char*convert(const char*what);
+    const char*get_original(){return source.c_str();}
+    const char*get_result(){return dest.c_str();}
 protected:
-    std::string dest;
-    std::string source;
+    string dest;
+    string source;
     stringlist source_idents;
     stringlist target_idents;
     int count;
