@@ -5,13 +5,10 @@
 
 #include <qlist.h>
 #include <qlined.h>
-#include <qlayout.h>
-#include <qcheckbox.h>
-#include <qpushbutton.h>
 
 #include "granteditdata.h"
 #include "PatternPair.h"
-#include "kmysqladmin/helpers/stringlist.h"
+#include "stringlist.h"
 
 class CGrantEdit : public CGrantEditData
 {
@@ -21,12 +18,11 @@ public:
     virtual ~CGrantEdit();
     void set_entries(PatternList*Patterns,stringlist*titles);
     PatternList*get_entries();
-protected:
+private:
     PatternList* OrigPatterns;
     int EditCounts;
     QList<QLineEdit>*WidgetList;
     void set_yesno(const char*name,QCheckBox*box,PatternList*pats);
-    QBoxLayout*EditLayout;
 private slots:
     void change_focus();
 };
