@@ -7,24 +7,17 @@
 
 #include <qstring.h>
 #include <qmsgbox.h>
-#include <klocale.h>
+#include <kwm.h>
 #include <kapp.h>
-#include <kglobal.h>
 
 #include "globals.h"
 #include "granttable.h"
 #include "grantedit.h"
-#include "my_sql.h"
-#include "stringres.h"
-#include "kmysqladmin/setup/settings.h"
-#include "TabView.h"
-#include "qlistview.h"
-
-#include "stringres.h"
+#include "mysqlw.h"
 
 #ifndef rcsid
-static const char rcsid[]="$Id: granttable.cpp,v 2.23 2003/02/09 17:54:35 ral Exp $";
-//const char*granttable_rcs(){return rcsid;}
+static const char rcsid[]="$Id: granttable.cpp,v 2.5 1999/07/31 19:52:38 ral Exp $";
+const char*granttable_rcs(){return rcsid;}
 #endif
 
 //strings, strings, strings....
@@ -49,31 +42,26 @@ const char*CGrantTable::No="N";
 
 #define Inherited CGrantTableData
 
-using namespace std;
-
-CGrantTable::CGrantTable(smart_pointer<CMySql>& _sql_server,QWidget* parent,const char* name)
+CGrantTable::CGrantTable(QWidget* parent,const char* name)
     :Inherited( parent, name )
-{
-    sql_server = _sql_server;
+{     
     QString caption;
-    User_Title=GET_TEXT(25);
-    DB_Title=GET_TEXT(26);
-    P_Title=GET_TEXT(27);
-    P2_Title=GET_TEXT(28);
-    caption = GET_TEXT(125);
-    caption += GET_TEXT(29);
+	User_Title=i18n("User:");
+	DB_Title=i18n("Database:");
+	P_Title=i18n("Password:");
+	P2_Title=i18n("Retype Pass:");
+
+    caption = ProgName;
+    caption += i18n(" - Edit grants");
     setCaption(caption);
-    setIcon(kapp->icon());
-    FontChanged();
+    KWM::setIcon(winId(),kapp->getIcon());
+    KWM::setMiniIcon(winId(),kapp->getMiniIcon());
     DisableButtons();
     ReadHostTable();
-    connect(&GlobalSettings,SIGNAL(fixfont_changed()),this,SLOT(FontChanged()));
-    FontChanged();
 }
 
 CGrantTable::~CGrantTable()
 {
-    debug("Granttable: destruktor\n");
 }
 
 void CGrantTable::Refresh()
@@ -88,60 +76,62 @@ void CGrantTable::ReadHostTable()
     HostList->clear();
     if (!sql_server)
 	return;
+    //    erg = new QStrList;
+    //    erg->setAutoDelete(TRUE);
     erg.push_back(std::string(Host_Table));
     erg.push_back(std::string(DB_Table));
-    HostList->clear();
-    list_vector result;
-    i = sql_server->fetch_rows(DB_Name,Host_Table,Host_Table,&erg,result,0,0,0,true);
-    if (result.size() > 0 && i==0) {
-        QListViewItem * item = 0;
-        list_vector::iterator result_iter = result.begin();
-	stringlist::iterator iter;
-	for (;result_iter!=result.end();++result_iter) {
-            iter = result_iter->begin();
-            item = new QListViewItem(HostList,item);
-            int count = 0;
-            for (;iter!=result_iter->end();++iter) {
-                item->setText(count,iter->c_str());
-                ++count;
-                if (count == 2)break;
-            }
+    i = sql_server->fetch_rows(DB_Name,Host_Table,Host_Table,&erg);
+    if (erg.size() > 0 && i==0) {
+	stringlist::iterator iter = erg.begin();
+	for (;iter!=erg.end();++iter) {
+	    HostList->insertItem(iter->c_str());
 	}
-    } else {
+	//	delete erg;
     }
-    HostList->setCurrentItem(HostList->firstChild());
-    hosthilighted(HostList->firstChild());
+    if (HostList->count() > 0 && i == 0)
+	HostList->setCurrentItem(0);
     if (i == 0)
 	AddHostButton->setEnabled(TRUE);
 }
 
-void CGrantTable::hosthilighted(QListViewItem*hostitem)
+void CGrantTable::hosthilighted(int i)
 {
-    if (hostitem==0)
-        return;
-    QString t = hostitem->text(0);
+    QString s = HostList->text(i);
+    QString t;
+    int j = s.find("\t");
+    if (j > -1) {
+	t = s.left(j);
+	t = t.stripWhiteSpace();
+	if (t == "%")
+	    t = "%%";
+    }
+    else
+	t = s;
     ReadUserTable(t);
     ModifyHostButton->setEnabled(TRUE);
-    if (UserList->childCount() > 0)
+    if (UserList->count() > 0)
 	DelHostButton->setEnabled(FALSE);
     else
-        DelHostButton->setEnabled(TRUE);
+	DelHostButton->setEnabled(TRUE);
 }
 
-void CGrantTable::userhilighted(QListViewItem*useritem)
+void CGrantTable::userhilighted(int i)
 {
-    if (useritem==0)
-        return;
-    QString t,s;
-    t = useritem->text(0);
-    s = useritem->text(1);
-    ReadDBTable(t,s);
-
+    QString s = UserList->text(i);
+    QString t;
+    int j = s.find("\t");
+    if (j > -1) {
+	t = s.left(j);
+	s = s.mid(j+1,s.length());
+	t = t.stripWhiteSpace();
+	s = s.stripWhiteSpace();
+	ReadDBTable(t,s);
+    }
     ModifyUserButton->setEnabled(TRUE);
-    if (DBList->childCount() == 0)
+    if (DBList->count() == 0)
 	DelUserButton->setEnabled(TRUE);
     else
-        DelUserButton->setEnabled(FALSE);
+	DelUserButton->setEnabled(FALSE);
 }
 
 void CGrantTable::show()
@@ -149,39 +139,31 @@ void CGrantTable::show()
     QDialog::show();
 }
 
-void CGrantTable::ReadUserTable(QString&Host)
+void CGrantTable::ReadUserTable(const char*Host)
 {
-    stringlist erg;
+    stringlist erg ;
     PatternList Patterns;
     int i;
 
     UserList->clear();
-    if (!sql_server)
+    if (!Host || !sql_server)
 	return;
     erg.push_back(Host_Table);
     erg.push_back(User_Table);
-    list_vector result;
+    //    Patterns=new PatternList;
+//    Patterns->setAutoDelete(TRUE);
     Patterns.push_back(CPatternPair(Host_Table,Host));
-    i = sql_server->fetch_rows(DB_Name,User_Table,User_Table,&erg,result,0,0,&Patterns,true);
+    i = sql_server->fetch_rows(DB_Name,User_Table,User_Table,&erg,0,0,&Patterns);
 
-    if (result.size()) {
-        QListViewItem* item=0;
-        list_vector::iterator result_iter=result.begin();
-	stringlist::iterator iter;
-        for (;result_iter!=result.end();++result_iter) {
-            iter = result_iter->begin();
-            item = new QListViewItem(UserList,item);
-            int count = 0;
-            for (;iter!=result_iter->end();++iter) {
-                item->setText(count,iter->c_str());
-                ++count;
-                if (count == 2)break;
-            }
-        }
+    if (erg.size()) {
+	stringlist::iterator iter = erg.begin();
+	for (;iter != erg.end();++iter) {
+	    UserList->insertItem(iter->c_str());
+	}
     }
-    if (UserList->childCount()>0 && i == 0) {
-	UserList->setCurrentItem(UserList->firstChild());
-    } else {
+    if (UserList->count()>0 && i == 0)
+	UserList->setCurrentItem(0);
+    else {
 	ModifyUserButton->setEnabled(FALSE);
 	DelUserButton->setEnabled(FALSE);
     }
@@ -191,7 +173,7 @@ void CGrantTable::ReadUserTable(QString&Host)
 	AddUserButton->setEnabled(FALSE);
 }
 
-void CGrantTable::ReadDBTable(QString&Host,QString&User)
+void CGrantTable::ReadDBTable(const char*Host,const char*User)
 {
     stringlist erg;
     PatternList Patterns;
@@ -199,36 +181,29 @@ void CGrantTable::ReadDBTable(QString&Host,QString&User)
     int i;
 
     DBList->clear();
-    if (!sql_server)
+    if (!Host || !User || !sql_server)
 	return;
 
     erg.push_back(Host_Table);
     erg.push_back(User_Table);
     erg.push_back(DB_Table);
-    list_vector result;
 
     Patterns.push_back(CPatternPair(Host_Table,Host));
     Patterns.push_back(CPatternPair(User_Table,User));
 
-    i = sql_server->fetch_rows(DB_Name,DB_Table,DB_Table,&erg,result,0,0,&Patterns,true);
-    if (result.size() && i==0) {
-        QListViewItem*item = 0;
-        list_vector::iterator result_iter = result.begin();
-	stringlist::iterator iter;
-        for (;result_iter!=result.end();++result_iter) {
-            iter = result_iter->begin();
-            item = new QListViewItem(DBList,item);
-            int count = 0;
-            for (;iter!=result_iter->end();++iter) {
-                item->setText(count,iter->c_str());
-                ++count;
-                if (count==3)break;
-            }
-        }
-        DBList->setCurrentItem(DBList->firstChild());
-    } else {
-        ModifyDbButton->setEnabled(FALSE);
-        DelDbButton->setEnabled(FALSE);        
+    i = sql_server->fetch_rows(DB_Name,DB_Table,DB_Table,&erg,0,0,&Patterns);
+    if (erg.size()) {
+	stringlist::iterator iter = erg.begin();
+	for (;iter!=erg.end();++iter) {
+	    DBList->insertItem(iter->c_str());
+	}
+	if (erg.size() > 0) {
+	    DBList->setCurrentItem(0);
+	}
+	else {
+	    ModifyDbButton->setEnabled(FALSE);
+	    DelDbButton->setEnabled(FALSE);
+	}
     }
     if (i == 0) 
 	AddDbButton->setEnabled(TRUE);
@@ -249,16 +224,10 @@ void CGrantTable::DisableButtons()
     DelDbButton->setEnabled(FALSE);
 }
 
-void CGrantTable::dbhilighted(QListViewItem*)
+void CGrantTable::dbhighlighted(int)
 {
-    QListViewItem*item = DBList->currentItem();
-    if (item) {
-        ModifyDbButton->setEnabled(TRUE);
-        DelDbButton->setEnabled(TRUE);
-    } else {
-        ModifyDbButton->setEnabled(FALSE);
-        DelDbButton->setEnabled(FALSE);
-    }
+    ModifyDbButton->setEnabled(TRUE);
+    DelDbButton->setEnabled(TRUE);
 }
 
 void CGrantTable::ModifyHost()
@@ -289,7 +258,7 @@ void CGrantTable::ModifyHost()
     if (db == "%")
 	(*Patterns)[1].set_pattern("%%");
     
-    i = sql_server->fetch_rows(DB_Name,Host_Table,0,&erg,0,0,Patterns,true);
+    i = sql_server->fetch_rows(DB_Name,Host_Table,0,&erg,0,0,Patterns);
 
     if (i == -1 || Patterns->size() == 0) {
 	Error();
@@ -298,11 +267,11 @@ void CGrantTable::ModifyHost()
     }
     Patterns->insert(Patterns->begin(),CPatternPair(DB_Table,db));
     Patterns->insert(Patterns->begin(),CPatternPair(Host_Table,host));
-    if (UserList->childCount() > 0)
+    if (UserList->count() > 0)
 	(*Patterns)[0].setIsNumeric(TRUE);
     erg.clear();
     erg.push_back(Host_Title);
-    erg.push_back(DB_Title.latin1());
+    erg.push_back(DB_Title);
     edit.set_entries(Patterns,&erg);
 
     if (edit.exec()) {
@@ -312,7 +281,8 @@ void CGrantTable::ModifyHost()
 	    Patterns->push_back(CPatternPair(Host_Table,host));
 	    Patterns->push_back(CPatternPair(DB_Table,db));
 	    i = sql_server->update_row(DB_Name,Host_Table,modify,Patterns);
-	    UpdateGrants(i);
+	    if (i < 0)
+		Error();
 	}
     }
 
@@ -326,14 +296,15 @@ void CGrantTable::ModifyUser()
     QString Host = "";
     QString User = "";
     QString result;
-    std::string Old_Pass;
-    std::string p1,p2;
+    QString Old_Pass;
+    QString p1,p2;
     stringlist erg;
     PatternList*Patterns = 0;
     PatternList*modify = 0;
     CPatternPair pat2;
     CGrantEdit edit(this);
-    edit.setCaption(GET_TEXT(30));
+    char*n_pass = 0;
+    edit.setCaption(i18n("Edit User-Rights"));
     int i = 0;
     int j = 0;
 
@@ -349,17 +320,11 @@ void CGrantTable::ModifyUser()
 	return;
 
     Host = (*Patterns)[0].get_pattern();
-    if (Host == "%")
-	(*Patterns)[0].set_pattern("%%");
     User = (*Patterns)[1].get_pattern();
-    if (User == "%")
-	(*Patterns)[1].set_pattern("%%");
 
-    i = sql_server->fetch_rows(DB_Name,User_Table,0,&erg,0,0,Patterns,true);
+    i = sql_server->fetch_rows(DB_Name,User_Table,0,&erg,0,0,Patterns);
     if (i == -1 || Patterns->size() == 0) {
 	Error();
-        if (Patterns->size()==0) 
-            qWarning("Patternsize == 0");
 	delete Patterns;
 	return;
     }
@@ -370,44 +335,47 @@ void CGrantTable::ModifyUser()
     (*Patterns)[0].setIsPassword(TRUE);
 
     Patterns->insert(Patterns->begin(),CPatternPair(User_Table,User));
-    (*Patterns)[0].setIsNumeric( (DBList->childCount() > 0) );
+    (*Patterns)[0].setIsNumeric( (DBList->count() > 0) );
+    
     Patterns->insert(Patterns->begin(),CPatternPair(Host_Table,Host));
     (*Patterns)[0].setIsNumeric(TRUE);
 
     erg.clear();
     erg.push_back(Host_Title);
-    erg.push_back(User_Title.latin1());
-    erg.push_back(P_Title.latin1());
-    erg.push_back(P2_Title.latin1());
+    erg.push_back(User_Title);
+    erg.push_back(P_Title);
+    erg.push_back(P2_Title);
     edit.set_entries(Patterns,&erg);
     erg.clear();
-    j = DBList->childCount() > 0?0:1;
+    j = DBList->count() > 0?0:1;
     if (edit.exec()) {
 	modify = edit.get_entries();
 	if (modify && modify->size()>0) {
 	    p1 = (*modify)[j].get_pattern();
+	    //	p1 = pat->get_pattern();
 	    p2 = (*modify)[j+1].get_pattern();
+	    //	p2 = pat->get_pattern();
 	    if (p1 != p2) {
 		pass_error();
 	    } else {
-		if (p1 == "") {
+		if (p1 == "")
 		    Old_Pass = "";
-		} else if (p1 != Old_Pass) {
-		    sql_server->scramble_password(p1);
+		else if (p1 != Old_Pass) {
+		    n_pass = sql_server->scramble_password(p1);
+		    if (n_pass) {
+			Old_Pass = n_pass;
+			delete[]n_pass;
+		    }
 		}
-		pat2 = (*modify)[0];
 		modify->erase(modify->begin());
 		modify->erase(modify->begin());
-		modify->erase(modify->begin());
-		if (p1 == string("user"))
-		    modify->insert(modify->begin(),pat2);
-                modify->insert(modify->begin(),CPatternPair(Pass_Entry,p1));
+		modify->insert(modify->begin(),CPatternPair(Pass_Entry,Old_Pass));
 		Patterns->clear();
 		Patterns->push_back(CPatternPair(Host_Table,Host));
 		Patterns->push_back(CPatternPair(User_Table,User));
 		i = sql_server->update_row(DB_Name,User_Table,modify,Patterns);
-		UpdateGrants(i);
-		ReadUserTable(Host);
+		if (i < 0)
+		    Error();
 	    }
 	}
     }
@@ -427,23 +395,39 @@ void CGrantTable::ModifyDb()
     PatternList*modify = 0;
     
     CGrantEdit edit(this);
-    edit.setCaption(GET_TEXT(31));
+    edit.setCaption(i18n("Edit DB-Rights"));
+    
+    int i = DBList->currentItem();
+    int j = 0;
+    if (i<0)
+	return;
+    dbentry = DBList->text(i);
+    j = dbentry.find("\t");
+    if (j < 0)
+	return;
 
     append_Sel(&erg);
+
     Patterns = break_dbstring();
     if (Patterns == 0)
-        return;
+	return;
 
+    /*    pat = Patterns->at(0);
+	  hostentry = pat->get_pattern();*/
     hostentry = (*Patterns)[0].get_pattern();
+    /*    pat = Patterns->at(1);
+	  userentry = pat->get_pattern();*/
     userentry = (*Patterns)[1].get_pattern();
+    /*    pat = Patterns->at(2);
+	  dbentry = pat->get_pattern();*/
     dbentry = (*Patterns)[2].get_pattern();
 
-    int i = sql_server->fetch_rows(DB_Name,DB_Table,0,&erg,0,0,Patterns,true);
+    i = sql_server->fetch_rows(DB_Name,DB_Table,0,&erg,0,0,Patterns);
 
     if (i == -1 || Patterns->size() == 0) {
-        Error();
-        delete Patterns;
-        return;
+	Error();
+	delete Patterns;
+	return;
     }
     Patterns->insert(Patterns->begin(),CPatternPair(DB_Table,dbentry));
     Patterns->insert(Patterns->begin(),CPatternPair(User_Table,userentry));
@@ -452,28 +436,25 @@ void CGrantTable::ModifyDb()
     (*Patterns)[0].setIsNumeric(TRUE);
     erg.clear();
     erg.push_back(Host_Title);
-    erg.push_back(User_Title.latin1());
-    erg.push_back(DB_Title.latin1());
+    erg.push_back(User_Title);
+    erg.push_back(DB_Title);
     edit.set_entries(Patterns,&erg);
 
     if (edit.exec()) {
- 	modify = edit.get_entries();
- 	if (modify && modify->size() > 0) {
-            Patterns->clear();
- 	    Patterns->push_back(CPatternPair(Host_Table,hostentry));
- 	    Patterns->push_back(CPatternPair(User_Table,userentry));
- 	    Patterns->push_back(CPatternPair(DB_Table,dbentry));
- 	    i = sql_server->update_row(DB_Name,DB_Table,modify,Patterns);
- 	    UpdateGrants(i);
-            QListViewItem*item = UserList->selectedItem();
-            if (item) {
-                userhilighted(item);
-            }
- 	}
+	modify = edit.get_entries();
+	if (modify && modify->size() > 0) {
+	    Patterns->clear();
+	    Patterns->push_back(CPatternPair(Host_Table,hostentry));
+	    Patterns->push_back(CPatternPair(User_Table,userentry));
+	    Patterns->push_back(CPatternPair(DB_Table,dbentry));
+	    i = sql_server->update_row(DB_Name,DB_Table,modify,Patterns);
+	    if (i < 0)
+		Error();
+	}
     }
     delete Patterns;
     if (modify)
-        delete modify;
+	delete modify;
 }
 
 void CGrantTable::append_Sel(stringlist*List)
@@ -503,29 +484,36 @@ void CGrantTable::append_Add(PatternList*List)
 void CGrantTable::AddHost()
 {
     PatternList*Patterns = 0;
+    //    CPatternPair*pat = 0;
     stringlist erg;
     QString host = "";
     QString db = "";
     int i;
     CGrantEdit edit(this);
     Patterns=new PatternList;
-    edit.setCaption(GET_TEXT(32));
+    edit.setCaption(i18n("Add Host"));
     Patterns->push_back(CPatternPair(Host_Table,""));
     Patterns->push_back(CPatternPair(DB_Table,""));
     
     erg.push_back(Host_Title);
-    erg.push_back(DB_Title.latin1());
+    erg.push_back(DB_Title);
     append_Add(Patterns);
     edit.set_entries(Patterns,&erg);
     delete Patterns; Patterns = 0;
     if (edit.exec()) {
 	Patterns = edit.get_entries();
+	//	pat = Patterns->first();
 	host = Patterns->begin()->get_pattern();
+	/*	pat = Patterns->at(1);
+	db = pat->get_pattern();
+	*/
 	db = (*Patterns)[1].get_pattern();
 	if (!db.isEmpty() && !host.isEmpty()) {
 	    i = sql_server->insert_row(DB_Name,Host_Table,Patterns);
-	    UpdateGrants(i);
-	    if (i > 0) {
+	    if (i < 0) {
+		Error();
+	    }
+	    else {
 		ReadHostTable();
 	    }
 	}
@@ -538,27 +526,43 @@ void CGrantTable::AddHost()
 void CGrantTable::AddUser()
 {
     QString Host = "";
+    char*n_pass = 0;
     PatternList*Patterns = 0;
     stringlist erg;
+
     CGrantEdit edit(this);
-    std::string p1, p2;
+    QString p1, p2;
+    int j = 0;
     int i = 0;
-    edit.setCaption(GET_TEXT(33));
+    edit.setCaption(i18n("Add User"));
     Patterns = break_hoststring();
     PatternList::iterator p_iter;
     if (Patterns == 0)
-        return;
+	return;
     (*Patterns)[0].setIsNumeric(TRUE);
+    //    pat = Patterns->at(0);
+    //    pat->setIsNumeric(TRUE);
+    //    Host = pat->get_pattern();
     Host = (*Patterns)[0].get_pattern();
     p_iter = Patterns->begin();
     ++p_iter;
     Patterns->erase(p_iter);
     Patterns->push_back(CPatternPair(User_Table,""));
+    /*
+      pat = new CPatternPair("pass","");
+      pat->setIsPassword(TRUE);
+      Patterns->append(pat);
+    */
     Patterns->push_back(CPatternPair("pass",""));
-    PatternIterator p_iter2;
-    p_iter2 = Patterns->end();
-    --p_iter2;
+		PatternIterator p_iter2;
+		p_iter2 = Patterns->end();
+		--p_iter2;
     p_iter2->setIsPassword(TRUE);
+    /*
+      pat = new CPatternPair("pass2","");
+      pat->setIsPassword(TRUE);
+      Patterns->append(pat);
+    */
     Patterns->push_back(CPatternPair("pass2",""));
 		p_iter2 = Patterns->end();
 		--p_iter2;
@@ -571,42 +575,46 @@ void CGrantTable::AddUser()
     Patterns->push_back(CPatternPair(Fi_Str,No)); 
 
     erg.push_back(Host_Title);
-    erg.push_back(User_Title.latin1());
-    erg.push_back(P_Title.latin1());
-    erg.push_back(P2_Title.latin1());
+    erg.push_back(User_Title);
+    erg.push_back(P_Title);
+    erg.push_back(P2_Title);
     edit.set_entries(Patterns,&erg);
     erg.clear();
     delete Patterns; Patterns = 0;
     if (edit.exec()) {
 	Patterns = edit.get_entries();
+	//	pat = Patterns->at(0);
 	p1 = (*Patterns)[0].get_pattern();
-	if (p1.size()==0) {
+	if (p1.isEmpty()) {
 	    user_error();
 	} else {
+	    //	pat = Patterns->at(1);
 	    p1 = (*Patterns)[1].get_pattern();
+	    //	pat = Patterns->at(2);
 	    p2 = (*Patterns)[2].get_pattern();
 	    if (p1 != p2) {
 		pass_error();
 	    } else {
-		if (p1.size()) {
-		    sql_server->scramble_password(p1);
-		} else {
-                }
+		if (!p1.isEmpty()) {
+		    n_pass = sql_server->scramble_password(p1);
+		    p1 = n_pass;
+		    delete [] n_pass;
+		}
 		p_iter = Patterns->begin();
 		p_iter++;
 		Patterns->erase(p_iter);
 		p_iter = Patterns->begin();
 		p_iter++;
 		Patterns->erase(p_iter);
-                if (p1.size()) 
-                    Patterns->insert(Patterns->begin(),CPatternPair(Pass_Entry,p1));
+		Patterns->insert(Patterns->begin(),CPatternPair(Pass_Entry,p1));
 		Patterns->insert(Patterns->begin(),CPatternPair(Host_Table,Host));
 		i = sql_server->insert_row(DB_Name,User_Table,Patterns);
-		UpdateGrants(i);
-		if (i > 0) {
-                    QListViewItem*item = HostList->selectedItem();
-		    if (item) {
-			hosthilighted(item);
+		if (i < 0) {
+		    Error();
+		} else {
+		    j = HostList->currentItem();
+		    if (j > -1) {
+			hosthilighted(j);
 		    }
 		}
 	    }
@@ -617,89 +625,110 @@ void CGrantTable::AddUser()
 
 void CGrantTable::AddDb()
 {
-        int i = 0;
-        QString Host = "";
-        QString User = "";
-        QString Title = GET_TEXT(34);
-        stringlist titles;
-        PatternList*Patterns;
-        CGrantEdit edit(this);
+    int i = 0;
+    int j = 0;
+    QString Host = "";
+    QString User = "";
+    QString Title = i18n("Add Db to user ");
+    stringlist titles;
+    PatternList*Patterns;
+    CGrantEdit edit(this);
 
-        Patterns = break_userstring();
-        if (Patterns == 0)
-            return;
+    Patterns = break_userstring();
+    if (Patterns == 0)
+	return;
 
-        Host = (*Patterns)[0].get_pattern();
-        (*Patterns)[0].setIsNumeric(TRUE);
-        User = (*Patterns)[1].get_pattern();
-        (*Patterns)[1].setIsNumeric(TRUE);
-        Patterns->push_back(CPatternPair(DB_Table,""));
-        append_Add(Patterns);
-        Title+=User;
-        edit.setCaption(Title);
+    /*
+      pat = Patterns->at(0);
+      Host = pat->get_pattern();
+      pat->setIsNumeric(TRUE);
+    */
+    Host = (*Patterns)[0].get_pattern();
+    (*Patterns)[0].setIsNumeric(TRUE);
+    /*
+      pat = Patterns->at(1);
+      User = pat->get_pattern();
+      pat->setIsNumeric(TRUE);
+    */
+    User = (*Patterns)[1].get_pattern();
+    (*Patterns)[1].setIsNumeric(TRUE);
+    Patterns->push_back(CPatternPair(DB_Table,""));
+    append_Add(Patterns);
+    Title+=User;
+    edit.setCaption(Title);
 
-        titles.push_back(Host_Title);
-        titles.push_back(User_Title.latin1());
-        titles.push_back(DB_Title.latin1());
-        edit.set_entries(Patterns,&titles);
+    titles.push_back(Host_Title);
+    titles.push_back(User_Title);
+    titles.push_back(DB_Title);
+    edit.set_entries(Patterns,&titles);
     
-        delete Patterns; Patterns = 0;
+    delete Patterns; Patterns = 0;
 
-        if (!edit.exec())
-            return;
-        Patterns = edit.get_entries();
-        if (!Patterns)
-            return;
-        Patterns->insert(Patterns->begin(),CPatternPair(Host_Table,Host));
-        Patterns->insert(Patterns->begin(),CPatternPair(User_Table,User));
-        i = sql_server->insert_row(DB_Name,DB_Table,Patterns);
-        UpdateGrants(i);
-        if (i > 0) {
-            userhilighted(UserList->selectedItem());
-        }
+    if (!edit.exec())
+	return;
+    Patterns = edit.get_entries();
+    if (!Patterns)
+	return;
+    Patterns->insert(Patterns->begin(),CPatternPair(Host_Table,Host));
+    Patterns->insert(Patterns->begin(),CPatternPair(User_Table,User));
+    i = sql_server->insert_row(DB_Name,DB_Table,Patterns);
+    if (i < 0) {
+	Error();
+    }
+    else {
+	j = UserList->currentItem();
+	if (j > -1)
+	    userhilighted(j);
+    }
 }
 
 void CGrantTable::pass_error()
 {
-    QString msg = GET_TEXT(35);
+    QString msg = i18n("You had typed in different passwords");
     msg+=",\n";
-    msg+=GET_TEXT(36);
-    QMessageBox::warning(this,GET_TEXT(37), msg );
+    msg+=i18n("please try again");
+    QMessageBox::warning(this,
+			  i18n("Error with password"),
+			  msg );
 }
 
 void CGrantTable::user_error()
 {
-    QMessageBox::warning(this,GET_TEXT(38),GET_TEXT(39));
+    QMessageBox::warning(this,
+			  i18n("Error with Username"),
+			  i18n("You had not typed in a username"));
 }
 
 void CGrantTable::DeleteUser()
 {
-    if (DBList->childCount() != 0)
+    if (DBList->count() != 0)
 	return;
     PatternList*KeyList=0;
+
     int i = Ask_delete();
     if (i != QMessageBox::Yes)
-        return;
+	return;
 
     KeyList = break_userstring();
     if (!KeyList)
-        return;
+	return;
+
     i = sql_server->delete_row(DB_Name,User_Table,KeyList);
 
     delete KeyList;
 
     if (i < 0) {
-        Error();
-        return;
+	Error();
+	return;
     }
-    QListViewItem*item = HostList->selectedItem();
-    if (item)
-        hosthilighted(item);
+    i = HostList->currentItem();
+    if (i > -1)
+	hosthilighted(i);
 }
 
 void CGrantTable::DeleteHost()
 {
-    if (UserList->childCount() != 0)
+    if (UserList->count() != 0)
 	return;
     PatternList*KeyList=0;
     int i = Ask_delete();
@@ -719,6 +748,7 @@ void CGrantTable::DeleteHost()
 
 void CGrantTable::DeleteDb()
 {
+    int j = 0;
     PatternList*KeyList = 0;
     int i = Ask_delete();
     if (i != QMessageBox::Yes)
@@ -732,51 +762,79 @@ void CGrantTable::DeleteDb()
 	Error();
 	return;
     }
-    userhilighted(UserList->selectedItem());
+    j = UserList->currentItem();
+    if (j > -1)
+	userhilighted(j);
 }
 
 PatternList* CGrantTable::break_hoststring()
 {
-    QListViewItem * item = HostList->selectedItem();
-    if (!item)
-        return 0;
-    QString db,Host;
-    PatternList*KeyList = new PatternList;
-    db = item->text(1);
-    Host=item->text(0);
+    PatternList*KeyList = 0;
+    int j = HostList->currentItem();
+    if (j < 0)
+	return KeyList;
+    QString db = HostList->text(j);
+    j = db.find("\t");
+    if (j < 0)
+	return KeyList;
+    QString Host = db.left(j);
+    Host = Host.stripWhiteSpace();
+    db = db.mid(j+1,db.length());
+    db = db.stripWhiteSpace();
+    
+    KeyList = new PatternList;
+    //    KeyList->setAutoDelete(TRUE);
     KeyList->push_back(CPatternPair(Host_Table,Host));
     KeyList->push_back(CPatternPair(DB_Table,db));
+    
     return KeyList;
 }
 
 PatternList* CGrantTable::break_userstring()
 {
-   QListViewItem * item = UserList->selectedItem();
-   if (!item)
-       return 0;
-   PatternList*KeyList = 0;
-   QString user = item->text(1);
-   QString host = item->text(0);
-   host = host.stripWhiteSpace();
-   user = user.stripWhiteSpace();
-   KeyList = new PatternList;
-   KeyList->push_back(CPatternPair(Host_Table,host));
-   KeyList->push_back(CPatternPair(User_Table,user));
-   return KeyList;
+    int j = UserList->currentItem();
+    PatternList*KeyList = 0;
+    if (j < 0)
+	return KeyList;
+    QString user = UserList->text(j);
+    j = user.find("\t");
+    if (j < 0)
+	return KeyList;
+    QString host = user.left(j);
+    host = host.stripWhiteSpace();
+    user = user.mid(j+1,user.length());
+    user = user.stripWhiteSpace();
+
+    KeyList = new PatternList;
+    //    KeyList->setAutoDelete(TRUE);
+    KeyList->push_back(CPatternPair(Host_Table,host));
+    KeyList->push_back(CPatternPair(User_Table,user));
+
+    return KeyList;
 }
 
 PatternList* CGrantTable::break_dbstring()
 {
-    QListViewItem * item = DBList->selectedItem();
+    int j = DBList->currentItem();
     PatternList*KeyList = 0;
-    if (!item)
+    if (j < 0)
 	return KeyList;
-    QString db = item->text(2);
-    QString host = item->text(0);
-    QString user = item->text(1);
+    QString db = DBList->text(j);
+    j = db.find("\t");
+    if (j < 0) 
+	return KeyList;
+    QString host = db.left(j);
+    host = host.stripWhiteSpace();
+    db = db.mid(j+1, db.length());
+    j = db.find("\t");
+    if (j < 0)
+	return KeyList;
+    QString user = db.left(j);
     user = user.stripWhiteSpace();
+    db = db.mid(j+1, db.length());
     db = db.stripWhiteSpace();
     KeyList = new PatternList;
+    //    KeyList->setAutoDelete(TRUE);
     KeyList->push_back(CPatternPair(Host_Table,host));
     KeyList->push_back(CPatternPair(User_Table,user));
     KeyList->push_back(CPatternPair(DB_Table,db));
@@ -796,34 +854,17 @@ void CGrantTable::Error()
     display_error_box();
 }
 
-void CGrantTable::hostselected(QListViewItem*)
+void CGrantTable::hostselected(int)
 {
     ModifyHost();
 }
 
-void CGrantTable::userselected(QListViewItem*)
+void CGrantTable::userselected(int)
 {
     ModifyUser();
 }
 
-void CGrantTable::dbselected(QListViewItem*)
+void CGrantTable::dbselected(int)
 {
     ModifyDb();
 }
-
-void CGrantTable::UpdateGrants(int count)
-{
-    if (count < 0) {
-	Error();
-    } else if (count > 0) {
-	sql_server->refresh_grants();
-    }
-}
-
-void CGrantTable::FontChanged()
-{
-    QFont font = GlobalSettings.get_fixed_font();
-    HostList->setFont(font);
-    UserList->setFont(font);
-    DBList->setFont(font);
-}
