@@ -1,9 +1,9 @@
 /***************************************************************************
-                          latexconverter.cpp  -  description                
-                             -------------------                            
-    begin                : Sat Jul 3 1999                                   
-    copyright            : (C) 1999 by Rajko Albrecht                       
-    email                : Rajko.Albrecht@informatik.tu-chemnitz.de         
+                          latexconverter.cpp  -  description                              
+                             -------------------                                         
+    begin                : Sat Jul 3 1999                                           
+    copyright            : (C) 1999 by Rajko Albrecht                         
+    email                : Rajko.Albrecht@informatik.tu-chemnitz.de                                     
  ***************************************************************************/
 
 /***************************************************************************
@@ -14,8 +14,9 @@
  *   (at your option) any later version.                                   * 
  *                                                                         *
  ***************************************************************************/
-#ifdef WIN32
-#pragma warning ( disable : 4786 )
+#ifndef rcsid
+static const char rcsid[]="$Id: latexconverter.cpp,v 2.4 1999/07/30 00:30:36 ral Exp $";
+const char*latexconverter_rcs(){return rcsid;}
 #endif
 
 #include "latexconverter.h"
@@ -60,4 +61,3 @@ CLatexConverter::CLatexConverter()
 CLatexConverter::~CLatexConverter()
 {
 }
-
