@@ -1,5 +1,7 @@
-// -*-Mode: C++;-*-
+// -*-Mode: C++;-*- 
 /*
+ * $Id: tabledescr.h,v 2.7 1999/08/07 19:33:12 ral Exp $
+ *
  * TableDescriptor - Class
  * it will be used to wrap the sql-entries
  * into a class which can use with various forms of sql-server
@@ -8,10 +10,10 @@
 #ifndef table_descr_inc
 #define table_descr_inc
 
-#include "kmysqladmin/helpers/stringlist.h"
-#include "kmysqladmin/helpers/pairs.h"
-
-typedef std::vector<string_int_pair> pairIlist;
+#include <vector>
+#include <string>
+#include "liste.h"
+#include "stringlist.h"
 
 class CKeyDescriptor
 {
@@ -19,100 +21,95 @@ public:
     enum Types {NONE,PRIMARY,UNIQUE,INDEX,FOREIGN};
 private:
     std::string name;
-    pairIlist ColumnsList;
+    stringIlist ColumnsList;
     Types type;
     bool compound;
+
 public:
     CKeyDescriptor(){type = NONE;compound = false;}
     CKeyDescriptor(const CKeyDescriptor&);
     virtual ~CKeyDescriptor(){};
-
+    
     //compares name against a string
-    const int operator == (const char*what)const;
-    const int operator == (const std::string&what)const;
-    const int operator == (const unsigned char*what)const;
+    int operator == (const char*what);
+    int operator == (const std::string&what);
 
     //compares against another descriptor
-    const int operator == (const CKeyDescriptor&)const;
+    int operator == (const CKeyDescriptor&);
     CKeyDescriptor&operator= (const CKeyDescriptor&old);
 
-    //required for some stl-implementations
-    const int operator < (const CKeyDescriptor&)const;
-
+    void set_name(const char*n_name){name = n_name?n_name:"";}
     void set_name(const std::string&n_name){name = n_name;}
-    const char*get_name()const{return name.c_str();}
+    const char*get_name(){return name.c_str();}
 
     void setType(Types nType){type = nType;}
-    Types getType()const{return type;}
+    Types getType(){return type;}
 
-    bool is_UniqueKey(){return (type==PRIMARY||type==UNIQUE);}
-
-    int add_column_name(const std::string&column,const unsigned int size=0);
+    int add_column_name(const char*column);
+    void remove_column_name(const char*column);
+    bool contains_column_name(const char*column);
+    int add_column_name(const std::string&column);
     void remove_column_name(const std::string&column);
     bool contains_column_name(const std::string&column);
-    unsigned int column_size(const std::string&column);
 
     unsigned int column_count(){return ColumnsList.size();}
 
-    const pairIlist& get_ColList()const{return ColumnsList;}
+    const stringIlist get_ColList(){return ColumnsList;}
     const bool is_compound()const{return compound;}
     void set_compound(bool com = false){compound = com;}
-
 };
 
-inline const int CKeyDescriptor::operator ==(const std::string & what) const
+inline int CKeyDescriptor::operator ==(const char*what)
 {
-    return Caseequ()(name,what);
+    // cause all fields in mysql are caseinsensitive
+    return ( strcasecmp(name.c_str(),what) == 0);
 }
 
-inline const int CKeyDescriptor::operator ==(const char*what)const
+inline int CKeyDescriptor::operator ==(const CKeyDescriptor&what)
 {
-    if (what==0) {
-        if (name.size()==0) {
-            return true;
-        } else {
-            return false;
-        }
-    }
-    return Caseequ()(name,what);
+    return (strcasecmp(name.c_str(), what.name.c_str()) == 0);
 }
 
-inline const int CKeyDescriptor::operator < (const CKeyDescriptor&what)const
+inline int CKeyDescriptor::add_column_name(const std::string&column)
 {
-    return Casecmp()(name,what.name);
+    return (column.size() == 0)?0:add_column_name(column.c_str());
 }
 
-inline const int CKeyDescriptor::operator ==(const CKeyDescriptor&what)const
+inline void CKeyDescriptor::remove_column_name(const std::string&column)
 {
-    return Caseequ()(name, what.name);
+    if (column.size())
+	remove_column_name(column.c_str());
 }
 
-typedef std::vector<CKeyDescriptor> KeyList;
+inline bool CKeyDescriptor::contains_column_name(const std::string&column)
+{
+    return column.size()>0?contains_column_name(column.c_str()):false;
+}
+
+typedef my_vector<CKeyDescriptor> KeyList;
 typedef KeyList::iterator KeyList_iterator;
 
-class CColumnDescriptor
+class CColumnDescriptor 
 {
-    std::string name;
-    std::string Def;
-    std::string table;
+    string name;
+    string Def;
+    string table;
 
     int FieldType;
     int MaxLength;
     int MaxDecimals;
-
+    
     bool AutoIncrement;
-    bool PrimaryField;
+    bool KeyField;
     bool Binary;
     bool TimeStamp;
     bool ZeroFill;
     bool NotNull;
     bool Blob;
-    bool Text;
     bool PartOfMultiple;
     bool Numeric;
     bool UniqueValue;
     bool Unsigned;
-    bool Set;
 
     stringIlist Enums;
 
@@ -122,36 +119,37 @@ public:
     CColumnDescriptor(const CColumnDescriptor&old);
     CColumnDescriptor&operator=(const CColumnDescriptor&old);
 
+    void set_name(const char*Name){name = Name?Name:"";}
     void set_name(const std::string&Name){name=Name;}
-    const std::string&get_name()const{return name;}
+    const char*get_name(){return name.c_str();}
 
+    void set_default(const char*def){Def = def?def:"";}
     void set_default(const std::string&def){Def = def;}
     const char*get_default(){return Def.c_str();}
 
+    void set_table(const char*t){table = t?t:"";}
     void set_table(const std::string&t){table=t;}
     const char*get_table(){return table.c_str();}
-
+    
     void set_FieldType(int type){FieldType = type;}
     int get_FieldType(){return FieldType;}
 
     const stringIlist&enum_list(){return Enums;}
     void enum_list(const stringIlist&list){Enums = list;}
-    void empty_enum_list(){Enums.resize(0);}
-    void set_is_set(bool aSet){Set = aSet;}
-    bool get_is_set()const{return Set;}
-
-    bool contains_enum(std::string&what){return Enums.find(what)!=Enums.end();}
+    
+    bool contains_enum(std::string&what){return Enums.find(what)!=0;}
+    bool contains_enum(const char*what){return what?Enums.find(std::string(what)):false;}
     void insert_enum(std::string&what){if (!contains_enum(what))Enums.push_back(what);}
+    void insert_enum(const char*what){if (what&&!contains_enum(what))Enums.push_back(std::string(what));}
     void remove_enum(const std::string&what);
+    void remove_enum(const char*what){if (what) remove_enum(std::string(what));}
 
     void set_Unsigned(bool how){Unsigned = how;}
     bool is_Unsigned(){return Unsigned;}
     bool is_AutoIncrement(){return AutoIncrement;}
     void set_AutoIncrement(bool how){AutoIncrement = how;}
-
-    bool is_KeyField(){return (PrimaryField||UniqueValue||PartOfMultiple);}
-    bool is_UniqueKey(){return (PrimaryField||UniqueValue);}
-
+    bool is_KeyField(){return KeyField;}
+    void set_KeyField(bool how){KeyField = how;}
     bool is_Binary(){return Binary;}
     void set_Binary(bool how){Binary = how;}
     bool is_TimeStamp(){return TimeStamp;}
@@ -162,55 +160,44 @@ public:
     void set_NotNull(bool how){NotNull = how;}
     bool is_Blob(){return Blob;}
     void set_Blob(bool how){Blob = how;}
-    bool is_Text(){return Text;}
-    void set_Text(bool how){Text = how;}
-
     bool is_PartOfMultiKey(){return PartOfMultiple;}
     void set_PartOfMultiKey(bool how){PartOfMultiple = how;}
     bool is_Numeric(){return Numeric;}
     void set_Numeric(bool how){Numeric = how;}
-
-    bool is_Primary(){return PrimaryField;}
-    void set_Primary(bool how){PrimaryField = how;}
     bool is_Unique(){return UniqueValue;}
     void set_Unique(bool how){UniqueValue = how;}
-
     int get_MaxLength(){return MaxLength;}
     void set_MaxLength(int Length){MaxLength = Length;}
     int get_MaxDecimals(){return MaxDecimals;}
     void set_MaxDecimals(int Dec){MaxDecimals = Dec;}
 
     //compares name against a string
-    const int operator == (const char*what)const;
-    const int operator == (const std::string&what)const;
+    int operator == (const char*what);
+    int operator == (const std::string&what);
     //compares against another descriptor
-    const int operator == (const CColumnDescriptor&what)const;
-
+    int operator == (const CColumnDescriptor&what);
+    
     int operator != (const CColumnDescriptor&what){return !(*this==what);}
-
-    //required for some stl-implementations
-    const int operator < (const CColumnDescriptor&old)const{return name < old.name;}
 protected:
     void copy_old(const CColumnDescriptor*old);
 };
 
-inline const int CColumnDescriptor::operator ==(const std::string&what)const
+inline int CColumnDescriptor::operator ==(const char*what)
 {
-    return Caseequ()(name,what);
+    return what?(strcasecmp(name.c_str(),what) == 0):0;
 }
 
-inline const int CColumnDescriptor::operator ==(const char*what)const
+inline int CColumnDescriptor::operator ==(const std::string&what)
 {
-    return what?Caseequ()(name,what):0;
+    return (strcasecmp(name.c_str(),what.c_str()) == 0);
 }
 
-inline const int CColumnDescriptor::operator ==(const CColumnDescriptor&what)const
+inline int CColumnDescriptor::operator ==(const CColumnDescriptor&what)
 {
-
-    return Caseequ()(name,what.name);
+    return (strcasecmp(name.c_str(),what.name.c_str()) == 0);
 }
 
-typedef std::vector<CColumnDescriptor> ColumnList;
+typedef my_vector<CColumnDescriptor> ColumnList;
 typedef ColumnList::iterator ColumnList_iterator;
 
 #endif
